' *********************************************************************
' *                                                                   *
' * NOME SCRIPT: MapPrinter.vbs                                       *
' *                                                                   *
' * Script scritto da Alessandro Tani (Home Works S.p.A.)             *
' *                                                                   *
' * Versione 1.2 - Modificato l'ultima volta il 26/08/2009            *
' *                da Alessandro Tani                                 *
' * SCOPO:                                                            *
' *                                                                   *
' *  Logon Script per il caricamento delle stampanti di rete.         *
' *  L'assegnazione delle stampanti di rete avviene per macchina,     *
' *  ovvero tramite il gruppo di appartenenza delle macchine e in     *
' *  base alla sottorete od al site in cui queste macchine si trovano *
' *  al momento del logon dell'utente.                                *
' *                                                                   *
' * File di log: Nessuno                                              *
' *                                                                   *
' * PREREQUISITI:                                                     *
' *                                                                   *
' *  Devono esistere le seguenti cartelle e file:                     *
' *                                                                   *
' *  Nessuno                                                          *
' *                                                                   *
' * TESTO:                                                            *
' *                                                                   *
' *  Nessuno                                                          *
' *                                                                   *
' *********************************************************************

'Dichiariamo sempre le variabili
Option Explicit

'Non gestiamo gli errori
On Error Resume Next

'Definiamo gli oggetti
Dim objNetwork, objSystemInfo, objShell

'Definiamo le variabili
Dim strComputerName, strSite, strLocalIPAddress, strTerzoOttetto
Dim intPrimoOttetto, intSecondoOttetto, intTerzoOttetto, bContinua

'Impostiamo gli oggetti
Set objNetwork = CreateObject("WScript.Network")
set objSystemInfo = WScript.CreateObject("ADSystemInfo")
set objShell = WScript.CreateObject("WScript.Shell")
strComputerName = objShell.ExpandEnvironmentStrings("%COMPUTERNAME%")
strSite = objSystemInfo.SiteName

'Carichiamo le stampanti condivise a livello aziendale
'Select Case strSite
'	Case "Nome-Sito"
'		objNetwork.AddWindowsPrinterConnection "\\NomeServer\NomeCondivisioneStampante#1"
'       objNetwork.AddWindowsPrinterConnection "\\NomeServer\NomeCondivisioneStampante#1"
'End Select

'Assegnamo le stampanti in base al gruppo di appartenenza ed alla sottorete in cui si trova la macchina

'Determiniamo a qualre rete appartiene la macchina
strLocalIPAddress = GetIPAddress()
if strLocalIPAddress = "Non Specificato" Then
   strTerzoOttetto = "1" 'Impostiamo di default la Rete #1 (10.10.1.0/24)
Else 'La macchina ha un indirizzo IP valido
   intPrimoOttetto = InStr(1, strLocalIPAddress, ".")
   intSecondoOttetto = InStr(intPrimoOttetto+1, strLocalIPAddress, ".")
   intTerzoOttetto = InStr(intSecondoOttetto+1, strLocalIPAddress, ".")
   strTerzoOttetto = Mid(strLocalIPAddress,intSecondoOttetto+1, Len(strLocalIPAddress)-(intTerzoOttetto+2))   
End If

'Ufficio Nome Ufficio (NomeGruppo)
If IsMemberOf("NomeGruppo", strComputerName) Then
   Select Case strSite
	      Case "Nome-Sito"
		       Select Case strTerzoOttetto
			          Case 1 'Rete #1 (10.10.1.0/24)
		                    objNetwork.AddWindowsPrinterConnection "\\NomeServer\NomeCondivisioneStampante#1"
							objNetwork.AddWindowsPrinterConnection "\\NomeServer\NomeCondivisioneStampante#2"
                           	objNetwork.SetDefaultPrinter "\\NomeServer\NomeCondivisioneStampante#1"
				      Case 2 'Rete #2 (10.10.2.0/24)
		                    objNetwork.AddWindowsPrinterConnection "\\NomeServer\NomeCondivisioneStampante#3"
							objNetwork.AddWindowsPrinterConnection "\\NomeServer\NomeCondivisioneStampante#4"
                           	objNetwork.SetDefaultPrinter "\\NomeServer\NomeCondivisioneStampante#3"					  
				      Case 3 'Rete #3 (10.10.3.0/24)
		                    objNetwork.AddWindowsPrinterConnection "\\NomeServer\NomeCondivisioneStampante#5"
							objNetwork.AddWindowsPrinterConnection "\\NomeServer\NomeCondivisioneStampante#6"
                           	objNetwork.SetDefaultPrinter "\\NomeServer\NomeCondivisioneStampante#5"
			   End Select
   End Select
End If

'Funzioni
Function IsMemberOf(strGroupName, strComputerName)

  'Funzione per sapere a quale gruppo una macchina appartiene
  
  'Non gestiamo gli errori
  On Error Resume Next

  'Definiamo gli oggetti
  Dim objRootDSE, objConnection, objCommand, objFSO, objRecordSet
  
  'Definiamo le variabili
  Dim arrGroups, bIsMember, strGroups, strLocation

  'Impostiamo le costanti
  Const ADS_SCOPE_SUBTREE = 2

  'Impostiamo gli oggetti
  Set objRootDSE = GetObject("LDAP://rootDSE")
  Set objConnection = CreateObject("ADODB.Connection") 
  Set objCommand = CreateObject("ADODB.Command")
  objConnection.Provider = "ADsDSOObject"
  objConnection.Open "Active Directory Provider"
  
  'Eseguiamo la query in AD
  Set objCOmmand.ActiveConnection = objConnection
  objCommand.CommandText = "Select memberOf from 'LDAP://" & objRootDSE.Get("defaultNamingContext") & "' " & "Where objectClass='computer' and cn='" & strComputerName & "'"
  objCommand.Properties("Page Size") = 1000
  objCommand.Properties("Searchscope") = ADS_SCOPE_SUBTREE 
  Set objRecordSet = objCommand.Execute
  arrGroups = objRecordSet.Fields("memberOf")
  bIsMember = False
  Err.Clear
  If isArray(arrGroups) Then
	For Each strGroups In arrGroups
		If Err = 0 Then
			strLocation=instr(strGroups,",")
			strGroups=left(strGroups,strLocation-1)
			strGroups=mid(strGroups,4)
			If LCase(strGroups) = LCase(strGroupName) Then
				bIsMember = True
			End If
		End If
	Next
  End If 
  IsMemberOf = bIsMember
  
End Function

Function GetIPAddress()

  'Funzione per ottenere l'indirizzo IP locale di una macchina

  'Definiamo gli oggetti
  Dim objWMIService, objIPAddress
  
  'Definiamo le variabili
  Dim colIPAddress, strIPAddress

  'Impostiamo gli oggetti
  Set objWMIService = GetObject("winmgmts:{impersonationLevel=impersonate}!\\localhost\root\cimv2")
  Set objIPAddress = objWMIService.ExecQuery ("SELECT IPADDRESS FROM Win32_NetworkAdapterConfiguration where IPEnabled=TRUE")
  
  'Determiniamo l'indirizzo IP locale della macchina
  strIPAddress = "Non Specificato"
  For Each colIPAddress in objIPAddress
      If colIPAddress.IPAddress(0) <> "0.0.0.0" Then
	     strIPAddress = colIPAddress.IPAddress(0)
      End If
  Next
  
  GetIPAddress = strIPAddress
  
End Function


